@@ -1,6 +1,4 @@
 from pyilluminate.fake_illuminate import FakeIlluminate
-from pyilluminate import LEDColor
-import pytest
 
 
 def test_defaults():
@@ -14,8 +12,7 @@ def test_defaults():
 def test_set_values():
     light = FakeIlluminate()
     light.led = [1, 2, 90]
-    with pytest.warns(UserWarning, match="The LEDColor"):
-        light.color = LEDColor(red=85, green=10, blue=1)
+    light.color = (85, 10, 1)
     assert tuple(light.color) == (85, 10, 1)
     assert set(light.led) == set([1, 2, 90])
 
@@ -23,8 +20,7 @@ def test_set_values():
 def test_clear():
     light = FakeIlluminate()
     light.led = [1, 2, 90]
-    with pytest.warns(UserWarning, match="The LEDColor"):
-        light.color = LEDColor(red=85, green=10, blue=1)
+    light.color = (85, 10, 1)
     light.clear()
     assert tuple(light.color) == (85, 10, 1)
     assert len(light.led) == 0
@@ -33,8 +29,7 @@ def test_clear():
 def test_fill_array():
     light = FakeIlluminate()
     light.led = [1, 2, 90]
-    with pytest.warns(UserWarning, match="The LEDColor"):
-        light.color = LEDColor(red=85, green=10, blue=1)
+    light.color = (85, 10, 1)
     light.fill_array()
     assert tuple(light.color) == (85, 10, 1)
     assert set(light.led) == set(range(light.N_leds))
